package net.sf.itcb.common.server;

import javax.xml.namespace.QName;
import net.sf.itcb.common.business.exceptions.BusinessItcbException;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.ws.soap.SoapFault;
import org.springframework.ws.soap.SoapFaultDetail;
import org.springframework.ws.soap.server.endpoint.SoapFaultDefinition;
import org.springframework.ws.soap.server.endpoint.SoapFaultMappingExceptionResolver;

/**
 * This resolver allow to add custom exception mapping in soap fault for BusinessItcbException and his children
 * 
 * @author Pierre Le Roux
 */
public class EndpointExceptionResolver extends SoapFaultMappingExceptionResolver {


	
	protected void customizeFault(Object endpoint, Exception ex, SoapFault fault) {
		if (ex instanceof BusinessItcbException) {
			BusinessItcbException bie = (BusinessItcbException) ex;
			SoapFaultDetail detail = fault.addFaultDetail();
			detail.addFaultDetailElement(BusinessItcbException.EXCEPTION_CLASS).addText(ex.getClass().getName());   
			detail.addFaultDetailElement(BusinessItcbException.COMMON_MESSAGE).addText(bie.getMessage());   
		}
	}

	@Override
	protected SoapFaultDefinition getFaultDefinition(Object endpoint, Exception ex) {
		SoapFaultDefinition soapFaultDefinition = super.getFaultDefinition(endpoint, ex);
		if (ex instanceof BusinessItcbException) {
			BusinessItcbException bie = (BusinessItcbException) ex;
			soapFaultDefinition.setFaultCode( new QName(BusinessItcbException.ITCB_NAMESPACE_URI,bie.getMessageKey(), "itcb"));
			soapFaultDefinition.setFaultStringOrReason(bie.getLocalizedMessage());
			soapFaultDefinition.setLocale(LocaleContextHolder.getLocale());
		}
		
        return soapFaultDefinition;

	}
	
	
	
	
}